<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=cs
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// 0
	'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
	'0_langue' => 'Čeština [cs]',
	'0_liste' => 'spip-cs@rezo.net',
	'0_mainteneur' => 'otto@pacholik.cz',

	// A
	'access_interface_graphique' => 'Zpět do kompletního grafického rozhraní',
	'access_mode_texte' => 'Zobrazit jednoduché textové rozhraní',
	'admin_debug' => 'ladění',
	'admin_modifier_article' => 'Změnit článek',
	'admin_modifier_auteur' => 'Změnit autora',
	'admin_modifier_breve' => 'Změnit tuto zprávu',
	'admin_modifier_mot' => 'Změnit klíčové slovo',
	'admin_modifier_rubrique' => 'Změnit sekci',
	'admin_recalculer' => 'Obnovit stránku',
	'afficher_trad' => 'vyvěsit překlady',
	'alerte_maj_impossible' => '<b>Varování!</b> Aktualizace databáze SQL na verzi @version@ se nezdařila. Je možné, že je to kvůli problémům s přístupovými právy k databázi. Kontaktujte svého poskytovatele připojení k internetu (ISP).',
	'alerte_modif_info_concourante' => 'VAROVÁNÍ: Tato informace byla změněna na jiném místě. Současná hodnota je :',
	'analyse_xml' => 'XML parsování',
	'annuler' => 'Storno',
	'antispam_champ_vide' => 'Tuto položku nechte prosím prázdnou:',
	'articles_recents' => 'Nedávné články',
	'avis_archive_incorrect' => 'soubor není platným SPIP archivem',
	'avis_archive_invalide' => 'neplatný soubor archívu',
	'avis_attention' => 'POZOR!',
	'avis_champ_incorrect_type_objet' => 'Naplatný název pole @name@ objektu typu @type@',
	'avis_colonne_inexistante' => 'Sloupec @col@ neexistuje',
	'avis_erreur' => 'Chyba: viz níže;',
	'avis_erreur_connexion' => 'Chyba při spojení',
	'avis_erreur_cookie' => 'Problémy se sušenkou :-) (cookie)',
	'avis_erreur_fonction_contexte' => 'Programátorská chyba. Funkce by neměla být v tomto kontextu volána.',
	'avis_erreur_mysql' => 'Chyba SQL',
	'avis_erreur_sauvegarde' => 'Chyba v zálohování (@type@ @id_objet@)!',
	'avis_erreur_visiteur' => 'Problém při vstupu do privátní zóny',

	// B
	'barre_a_accent_grave' => 'Zadejte velké A s obrácenou čárkou (`)',
	'barre_aide' => 'Vzhled stránek (layout) dolaďte pomocí typografických zkratek',
	'barre_e_accent_aigu' => 'Zadejte písmeno É',
	'barre_eo' => 'Zadejte písmeno oe',
	'barre_eo_maj' => 'Zadejte písmeno EO',
	'barre_euro' => 'Zadejte symbol €',
	'barre_gras' => 'Zadejte {{tučné písmo}}',
	'barre_guillemets' => 'Umístěte znaky do dvojitých uvozovek (")',
	'barre_guillemets_simples' => 'Umístěte znaky do jednoduchých uvozovek (‘)',
	'barre_intertitre' => 'Změňte na {{{podzáhlaví}}}',
	'barre_italic' => 'Zadejte {kurzívou}',
	'barre_lien' => 'Změnit na [hypertextový odkaz->http://...]',
	'barre_lien_input' => 'Zadejte cíl hypertextového odkazu (adresu URL ve formátu http://www.mysite.com nebo číslo článku na těchto stránkách).',
	'barre_note' => 'Změnit na [[poznámku pod čarou]]',
	'barre_paragraphe' => 'Vytvořit odstavec',
	'barre_quote' => '<quote>Citovat zprávu</quote>',
	'bouton_changer' => 'Změnit',
	'bouton_chercher' => 'Najít',
	'bouton_choisir' => 'Vybrat',
	'bouton_download' => 'Download', # MODIF
	'bouton_enregistrer' => 'Uložit',
	'bouton_radio_desactiver_messagerie_interne' => 'Vypnout interní hlášení',
	'bouton_radio_envoi_annonces' => 'Zaslat editorská oznámení',
	'bouton_radio_non_envoi_annonces' => 'Nezasílat žádná oznámení',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Nezasílat seznam nejnovějších zpráv',
	'bouton_recharger_page' => 'znovu načíst tuto stránku',
	'bouton_telecharger' => 'Odeslat',
	'bouton_upload' => 'Odeslat', # MODIF
	'bouton_valider' => 'Odeslat',

	// C
	'cal_apresmidi' => 'odpoledne',
	'cal_jour_entier' => 'celý den',
	'cal_matin' => 'dopoledne',
	'cal_par_jour' => 'zobrazení jednotlivých dnů',
	'cal_par_mois' => 'zobrazení celého měsíce',
	'cal_par_semaine' => 'zobrazení celých týdnů',
	'choix_couleur_interface' => 'barva',
	'choix_interface' => 'volba rozhraní',
	'colonne' => 'Sloupec',
	'confirm_changer_statut' => 'Je nutné potvrzení akce: Požádali jste o změnu stavu článku. Chcete pokračovat?',
	'correcte' => 'správně',

	// D
	'date_aujourdhui' => 'dnes',
	'date_avant_jc' => 'př. n. l.',
	'date_dans' => 'během @delai@',
	'date_de_mois_1' => '@j@ ledna',
	'date_de_mois_10' => '@j@ října',
	'date_de_mois_11' => '@j@ listopadu',
	'date_de_mois_12' => '@j@ prosince',
	'date_de_mois_2' => '@j@ února',
	'date_de_mois_3' => '@j@ března',
	'date_de_mois_4' => '@j@ dubna',
	'date_de_mois_5' => '@j@ května',
	'date_de_mois_6' => '@j@ června',
	'date_de_mois_7' => '@j@ července',
	'date_de_mois_8' => '@j@ srpna',
	'date_de_mois_9' => '@j@ září',
	'date_demain' => 'zítra',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_jour_heure' => '@jour@ a @heure@',
	'date_fmt_jour_mois' => '@jourmois@',
	'date_fmt_jour_mois_annee' => '@jourmois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour_date' => '@date@ @nomjour@',
	'date_heures' => 'hodin',
	'date_hier' => 'včera',
	'date_il_y_a' => 'před @delai@',
	'date_jnum1' => '1.',
	'date_jnum10' => '10.',
	'date_jnum11' => '11.',
	'date_jnum12' => '12.',
	'date_jnum13' => '13.',
	'date_jnum14' => '14.',
	'date_jnum15' => '15.',
	'date_jnum16' => '16.',
	'date_jnum17' => '17.',
	'date_jnum18' => '18.',
	'date_jnum19' => '19.',
	'date_jnum2' => '2.',
	'date_jnum20' => '20.',
	'date_jnum21' => '21.',
	'date_jnum22' => '22.',
	'date_jnum23' => '23.',
	'date_jnum24' => '24.',
	'date_jnum25' => '25.',
	'date_jnum26' => '26.',
	'date_jnum27' => '27.',
	'date_jnum28' => '28.',
	'date_jnum29' => '29.',
	'date_jnum3' => '3.',
	'date_jnum30' => '30.',
	'date_jnum31' => '31.',
	'date_jnum4' => '4.',
	'date_jnum5' => '5.',
	'date_jnum6' => '6.',
	'date_jnum7' => '7.',
	'date_jnum8' => '8.',
	'date_jnum9' => '9.',
	'date_jour_1' => 'neděle',
	'date_jour_1_abbr' => 'Ne.',
	'date_jour_1_initiale' => 'N.',
	'date_jour_2' => 'pondělí',
	'date_jour_2_abbr' => 'Po.',
	'date_jour_2_initiale' => 'P.',
	'date_jour_3' => 'úterý',
	'date_jour_3_abbr' => 'Út.',
	'date_jour_3_initiale' => 'Ú.',
	'date_jour_4' => 'středa',
	'date_jour_4_abbr' => 'St.',
	'date_jour_4_initiale' => 'S.',
	'date_jour_5' => 'čtvrtek',
	'date_jour_5_abbr' => 'Čt.',
	'date_jour_5_initiale' => 'Č.',
	'date_jour_6' => 'pátek',
	'date_jour_6_abbr' => 'Pá.',
	'date_jour_6_initiale' => 'P.',
	'date_jour_7' => 'sobota',
	'date_jour_7_abbr' => 'So.',
	'date_jour_7_initiale' => 'S.',
	'date_jours' => 'dnů',
	'date_minutes' => 'minut',
	'date_mois' => 'měsíců',
	'date_mois_1' => 'Leden',
	'date_mois_10' => 'Říjen',
	'date_mois_11' => 'Listopad',
	'date_mois_12' => 'Prosinec',
	'date_mois_2' => 'Únor',
	'date_mois_3' => 'Březen',
	'date_mois_4' => 'Duben',
	'date_mois_5' => 'Květen',
	'date_mois_6' => 'Červen',
	'date_mois_7' => 'Červenec',
	'date_mois_8' => 'Srpen',
	'date_mois_9' => 'Září',
	'date_saison_1' => 'zima',
	'date_saison_2' => 'jaro',
	'date_saison_3' => 'léto',
	'date_saison_4' => 'podzim',
	'date_semaines' => 'týdnů',
	'dirs_commencer' => 'pro vlastní zahájení instalace',
	'dirs_preliminaire' => 'Předběžná akce: <b>Nastavení přístupových práv</b>',
	'dirs_probleme_droits' => 'Problém s přístupovými právy',
	'dirs_repertoires_absents' => '<p><b>Nebyl nalezen adresář, resp. adresáře:</b></p> <ul>@bad_dirs@.</ul> 
  <p>Může to být kvůli nesprávnému zadání velkých a malých písmen.
  Zkontrolujte, zda malá a velká písmena uvedeného adresáře, resp. adresářů souhlasí s tím,
  co je uvedeno výše. Pokud ne, přejmenujte adresáře pomocí klienta programu FTP. Tím chybu opravíte.</p>
  <p>Poté můžete',
	'dirs_repertoires_suivants' => '<p><b>K následujícímu adresáři, resp. adresářům chybí právo zápisu:</b></p><ul>@bad_dirs@.</ul>
<p>Změňte tato práva pomocí klienta FTP a nastavte práva přístupu jednotlivých adresářů
  Podrobný popis je v návodu k instalaci.</p>
  <p>Poté můžete ',
	'double_occurrence' => 'Dvě instance', # MODIF

	// E
	'en_cours' => 'probíhá zpracování',
	'envoi_via_le_site' => 'Odeslat pomocí webu',

	// F
	'fichier_introuvable' => 'Nalezen nový soubor: @fichier@',
	'form_deja_inscrit' => 'Už jste zaregistrováni.',
	'form_email_non_valide' => 'Neplatná elektronická adresa.',
	'form_forum_access_refuse' => 'K tomuto webu již nemáte přístup.',
	'form_forum_bonjour' => 'Dobrý den @nom@,',
	'form_forum_email_deja_enregistre' => 'Tato elektronická adresa je již zaregistrována. Můžete tedy používat své obvyklé heslo.',
	'form_forum_identifiant_mail' => 'Nové identifikační údaje vám byly odeslány elektronickou poštou.',
	'form_forum_identifiants' => 'Osobní identifikační údaje',
	'form_forum_indiquer_nom_email' => 'Zadejte jméno a elektronickou adresu. Osobní identifikační údaje obdržíte v brzké době elektronickou poštou.',
	'form_forum_login' => 'Login:',
	'form_forum_message_auto' => '(toto je automatická zpráva)',
	'form_forum_pass' => 'Heslo:',
	'form_forum_probleme_mail' => 'Problémy s elektronickou poštou: Odeslání identifikačních údajů se nezdařilo.',
	'form_forum_voici1' => 'Zde jsou identifikační údaje umožňující účast na aktivitách tohoto webu
"@nom_site_spip@" (@adresse_site@):',
	'form_forum_voici2' => 'Zde jsou identifikační údaje, které vám umožní publikovat články
na webu "@nom_site_spip@" (@adresse_login@):',
	'form_indiquer_email' => 'Zadejte svůj e-mail.',
	'form_indiquer_nom' => 'Zadejte své jméno.',
	'form_indiquer_nom_site' => 'Zadejte název svého webu.',
	'form_pet_deja_enregistre' => 'Tento web je již zaregistrován',
	'form_pet_signature_pasprise' => 'Váš podpis nebyl zohledněn.',
	'form_prop_confirmer_envoi' => 'Potvrďte odeslání',
	'form_prop_description' => 'Popis/poznámka',
	'form_prop_enregistre' => 'Váš návrh byl zaregistrován. Po kontrole správci tohoto webu bude zvěřejněn online.',
	'form_prop_envoyer' => 'Odeslat zprávu',
	'form_prop_indiquer_email' => 'Zadejte platnou elektronickou adresu',
	'form_prop_indiquer_nom_site' => 'Zadejte název webu.',
	'form_prop_indiquer_sujet' => 'Zadejte předmět',
	'form_prop_message_envoye' => 'Zpráva byla odeslána',
	'form_prop_non_enregistre' => 'Váš návrh byl zaznamenán.',
	'form_prop_sujet' => 'Předmět',
	'form_prop_url_site' => 'Adresa URL webu', # MODIF
	'forum_non_inscrit' => 'Buď nejste zaregistrováni nebo jste zadali nesprávnou adresu či heslo.',
	'forum_par_auteur' => 'Autor: @auteur@',
	'forum_titre_erreur' => 'Chyba...',

	// I
	'ical_texte_rss_articles' => 'Adresa souboru na serveru (backend) článků na webu je:',
	'ical_texte_rss_articles2' => 'Můžete získat i serverové soubory k článkům z jednotlivých sekcí webu:',
	'ical_texte_rss_breves' => 'Dále existuje soubor obsahující novinky z webu. Zadáním čísla sekce získáte pouze novinky týkající se dané sekce.',
	'icone_a_suivre' => 'Hlavní nabídka',
	'icone_admin_site' => 'Správa webu',
	'icone_agenda' => 'Kalendář',
	'icone_aide_ligne' => 'Nápověda',
	'icone_articles' => 'Články',
	'icone_auteurs' => 'Autoři',
	'icone_brouteur' => 'Rychlé procházení',
	'icone_configuration_site' => 'Nastavení',
	'icone_configurer_site' => 'Nastavte svůj web',
	'icone_creer_nouvel_auteur' => 'Vytvořit nového autora',
	'icone_creer_rubrique' => 'Vytvořit sekci',
	'icone_creer_sous_rubrique' => 'Vytvořit podsekci',
	'icone_deconnecter' => 'Odhlásit',
	'icone_discussions' => 'Diskuse',
	'icone_doc_rubrique' => 'Dokumenty v příloze',
	'icone_ecrire_article' => 'Napsat nový článek',
	'icone_edition_site' => 'Editovat web',
	'icone_gestion_langues' => 'Správa jazyků',
	'icone_informations_personnelles' => 'Osobní údaje',
	'icone_interface_complet' => 'Úplné rozhraní',
	'icone_interface_simple' => 'Jednoduché rozhraní',
	'icone_maintenance_site' => 'Údržba webu',
	'icone_messagerie_personnelle' => 'Osobní zprávy',
	'icone_repartition_debut' => 'Zobrazit rozdělení od počátku',
	'icone_rubriques' => 'Sekce',
	'icone_sauver_site' => 'Uložení webu',
	'icone_site_entier' => 'Všechny stránky',
	'icone_sites_references' => 'Stránky na něž existují odkazy',
	'icone_statistiques' => 'Statistiky stránek',
	'icone_suivi_activite' => 'Sledování aktivity webu',
	'icone_suivi_actualite' => 'Statistiky stránek',
	'icone_suivi_pettions' => 'Správa peticí',
	'icone_suivi_revisions' => 'Revize článků',
	'icone_supprimer_document' => 'Odstranit dokument',
	'icone_supprimer_image' => 'Odstranit obrázek',
	'icone_tous_articles' => 'Všechny vaše články',
	'icone_tous_auteur' => 'Všichni autoři',
	'icone_visiter_site' => 'Zobrazit web', # MODIF
	'icone_voir_en_ligne' => 'Prohlížet online',
	'img_indisponible' => 'Obrázek není k dispozici',
	'impossible' => 'nemožné',
	'info_a_suivre' => 'HLAVNÍ NABÍDKA"',
	'info_acces_interdit' => 'Přístup zakázán',
	'info_acces_refuse' => 'Přístup odepřen',
	'info_action' => 'Akce: @action@',
	'info_administrer_rubriques' => 'Můžete provádět údržbu této sekce a jejích podsekcí',
	'info_adresse_non_indiquee' => 'Nezadali jste, která adresa se má otestovat!',
	'info_aide' => 'NÁPOVĚDA:',
	'info_ajouter_mot' => 'Přidat klíčové slovo',
	'info_annonce' => 'OZNÁMENÍ',
	'info_annonces_generales' => 'Obecná oznámení:',
	'info_article_propose' => 'Článek byl odeslán',
	'info_article_publie' => 'Článek byl zveřejněn',
	'info_article_redaction' => 'Články ve zpracování',
	'info_article_refuse' => 'Odmítnuté články',
	'info_article_supprime' => 'Odstraněné články',
	'info_articles' => 'Články',
	'info_articles_a_valider' => 'Články ke schválení',
	'info_articles_proposes' => 'Předložené články',
	'info_auteurs_nombre' => 'Autor či autoři:',
	'info_authentification_ftp' => 'Autentifikace (pomocí FTP).',
	'info_breves_2' => 'novinky',
	'info_connexion_refusee' => 'Spojení bylo odepřeno',
	'info_contact_developpeur' => 'Kontaktujte vývojáře.',
	'info_contenance' => 'Tyto stránky obsahují:',
	'info_contribution' => 'příspěvky do diskusní skupiny', # MODIF
	'info_copyright' => '@spip@ je freeware distribuovaný @lien_gpl@.',
	'info_copyright_doc' => 'Bližší informace viz <a href="@spipnet@">http://www.spip.net/en</a>.', # MODIF
	'info_copyright_gpl' => 'v rámci licence GPL',
	'info_cours_edition' => 'Vaše rozpracované články',
	'info_creer_repertoire' => 'Vytvořte soubor nebo adresář s názvem:',
	'info_creer_repertoire_2' => 'v podadresáři <b>@repertoire@</b>. Potom',
	'info_creer_vignette' => 'automatické vytvoření náhledu',
	'info_deplier' => 'Rozbalit',
	'info_descriptif_nombre' => 'Popis:',
	'info_description' => 'Popis:',
	'info_description_2' => 'Popis:',
	'info_dimension' => 'Velikost:',
	'info_ecire_message_prive' => 'Napsat soukromou zprávu',
	'info_email_invalide' => 'Neplatný e-mail.',
	'info_en_cours_validation' => 'Vaše rozpracované články',
	'info_en_ligne' => 'Nyní online:',
	'info_envoyer_message_prive' => 'Odeslat soukromou zprávu tomuto autorovi',
	'info_erreur_requete' => 'Chyba při databázovém dotazu:',
	'info_erreur_squelette2' => 'Neexistující šablona <b>@fichier@</b>...',
	'info_erreur_systeme' => 'Systémová chyba (číslo: @errsys@)',
	'info_erreur_systeme2' => 'Pevný disk může být plný nebo může být poškozen. <br />
<span style="color:red;">Zkuste <a href=\'@script@\'>opravit databázi</a>, nebo kontaktujte svého poskytovatele prostoru pro web.</span>', # MODIF
	'info_fini' => 'Hotovo!',
	'info_format_image' => 'Formát obrázku pro tvorbu náhledů: @gd_formats@.',
	'info_format_non_defini' => 'formát není definován',
	'info_grand_ecran' => 'Velké zobrazení',
	'info_image_aide' => 'NÁPOVĚDA',
	'info_image_process_titre' => 'Návod k vytvoření náhledů',
	'info_impossible_lire_page' => '<b>Chyba!</b> Stránku nelze číst <tt><html>@test_proxy@</html></tt> přes proxy bránu <tt>', # MODIF
	'info_installation_systeme_publication' => 'Instalace publikačního systému ...',
	'info_installer_documents' => 'Všechny dokumenty ve složce @upload@ lze nainstalovat automaticky.',
	'info_installer_ftp' => 'Jako správce můžete instalovat (pomocí FTP) soubory do složky @upload@ a následně je odtamtud můžete přímo vybírat.',
	'info_installer_images' => 'Obrázky lze instalovat ve formátu JPEG, GIF a PNG.',
	'info_installer_images_dossier' => 'Nainstalujte obrázky do složky @upload@, abyste je odtamtud mohli vybírat.',
	'info_interface_complete' => 'úplné rozhraní',
	'info_interface_simple' => 'jednoduché rozhraní',
	'info_joindre_document_article' => 'K článku lze připojit dokumenty ve formátu',
	'info_joindre_document_rubrique' => 'K této sekci můžete přidávat dokumenty ve formátu',
	'info_joindre_documents_article' => 'K článku můžete přidávat dokumenty ve formátu:',
	'info_l_article' => 'článek',
	'info_la_breve' => 'novinka',
	'info_la_rubrique' => 'sekce',
	'info_langue_principale' => 'Hlavní jazyk stránek',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ pixelů',
	'info_les_auteurs_1' => 'od @les_auteurs@',
	'info_logo_format_interdit' => 'Loga jsou povolena pouze ve formátu @formats@.',
	'info_logo_max_poids' => 'Log nesmí být větší než @maxi@ (tento soubor má velikost @actuel@).',
	'info_mail_fournisseur' => 'you@isp.com',
	'info_message_2' => 'ZPRÁVA',
	'info_message_supprime' => 'ZPRÁVA BYLA ODSTRANĚNA',
	'info_mise_en_ligne' => 'Datum zveřejnění online:',
	'info_modification_parametres_securite' => 'úprava bezpečnostních parametrů',
	'info_mois_courant' => 'V měsíci:',
	'info_mot_cle_ajoute' => 'Bylo přidáno toto klíčové slovo',
	'info_multi_herit' => 'Výchozí jazyk',
	'info_multi_langues_soulignees' => 'Jazyky <u>zobrazené podtrženě</u> mají přeloženo celé rozhraní. Pokue je zvolíte, bude automaticky přeložena celá řada položek veřejných stráneki(data, formuláře). U jazyků, které nejsou podtrženy, budou tyto položky zobrazeny v hlavním jazyce stránek.', # MODIF
	'info_multilinguisme' => 'Vícejazyčné',
	'info_nom_non_utilisateurs_connectes' => 'Vaše jméno není uvedeno na seznamu připojených uživatelů.',
	'info_nom_utilisateurs_connectes' => 'Vaše jméno je uvedeno na seznamu připojených uživatelů.',
	'info_nombre_en_ligne' => 'Aktuálně online:',
	'info_non_resultat' => 'Źádné výsledky pro "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'Nepoužíváte systém pro interní zasílání zpráv v rámci těchto stránek.',
	'info_nouveau_message' => 'MÁTE NOVOU ZPRÁVU',
	'info_nouveaux_messages' => 'MÁTE CELKEM @total_messages@ NOVÝCH ZPRÁV',
	'info_numero_abbreviation' => 'č.',
	'info_pense_bete' => 'POZNÁMKA',
	'info_petit_ecran' => 'Malý displej',
	'info_pixels' => 'pixelů',
	'info_plusieurs_mots_trouves' => 'Pro "@cherche_mot@" bylo nalezeno několik klíčových slov:',
	'info_portfolio_automatique' => 'Automatizované portfolio:',
	'info_premier_resultat' => '[@debut_limit@ prvních výsledků z @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ prvních výsledků z @total@]',
	'info_propose_1' => '[@nom_site_spip@] Předloženo: @titre@',
	'info_propose_2' => 'Předložen článek
-----------------',
	'info_propose_3' => 'Článek "@titre@" byl předložen ke zveřejnění.',
	'info_propose_4' => 'Prosím, přečtěte si jej a sdělte svůj názor',
	'info_propose_5' => 'v diskusní skupině, na níž navazuje. Je k dispozici na adrese:',
	'info_publie_01' => 'Článek "@titre@" byl schválen @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] ZVEŘEJNĚNO: @titre@',
	'info_publie_2' => 'Zveřejněný článek
-----------------',
	'info_rechercher' => 'Najít',
	'info_rechercher_02' => 'Najít:',
	'info_remplacer_vignette' => 'Nahradit standardní náhled vlastním logem:',
	'info_sans_titre_2' => 'bez názvu',
	'info_selectionner_fichier' => 'Můžete vybrat soubor ze složky @upload@',
	'info_selectionner_fichier_2' => 'Vybrat soubor:',
	'info_supprimer_vignette' => 'odstranit náhled',
	'info_symbole_bleu' => '<b>Modrým</b> symbolem je označena <b>interní poznámka</b>, tj. zpráva určená pro osobní potřebu.', # MODIF
	'info_symbole_jaune' => '<b>Žlutým</b> symbolem je označena <b>zpráva pro všechny redaktory</b>: může ji upravovat kterýkoli ze správců a zobrazuje se všem redaktorům.', # MODIF
	'info_symbole_vert' => '<b>Zeleným</b> symbolem jsou označeny <b>zprávy vyměňované s ostatními uživateli</b> webu.', # MODIF
	'info_telecharger_nouveau_logo' => 'Odeslat nové logo:',
	'info_telecharger_ordinateur' => 'Odeslat z počítače:',
	'info_tous_resultats_enregistres' => '[všechny výsledky jsou zapsány]',
	'info_tout_afficher' => 'Zobrazit vše',
	'info_travaux_texte' => 'Tyto stránky nejsou ještě nastaveny. Navštivte je, prosím, později...',
	'info_travaux_titre' => 'Na webu se pracuje',
	'info_trop_resultat' => 'Pro: "@cherche_mot@" bylo zobrazeno příliš mnoho výsledků. Zadejte podrobnější kritéria pro vyhledávání.',
	'info_utilisation_messagerie_interne' => 'U tohoto webu používáte systém interních zpráv.',
	'info_valider_lien' => 'schválit tento odkaz',
	'info_verifier_image' => ', zkontrolujte, zda jste obrázky přenesli správně.',
	'info_vignette_defaut' => 'Výchozí náhled',
	'info_vignette_personnalisee' => 'Vlastní náhled',
	'info_visite' => 'návštěvy:',
	'info_vos_rendez_vous' => 'Vaše budoucí schůzky',
	'infos_vos_pense_bete' => 'Vaše poznámky', # MODIF

	// L
	'lien_afficher_icones_seuls' => 'Zobrazit pouze ikony',
	'lien_afficher_texte_icones' => 'Zobrazit ikony a text',
	'lien_afficher_texte_seul' => 'Zobrazit pouze text',
	'lien_liberer' => 'verze',
	'lien_liberer_tous' => 'uvolnit tyto články', # MODIF
	'lien_nouvea_pense_bete' => 'NOVÁ POZNÁMKA',
	'lien_nouveau_message' => 'NOVÁ ZPRÁVA',
	'lien_nouvelle_annonce' => 'NOVÉ OZNÁMENÍ',
	'lien_petitions' => 'PETICE',
	'lien_popularite' => 'oblíbenost: @popularite@%',
	'lien_racine_site' => 'KOŘENOVÝ ADRESÁŘ STRÁNEK',
	'lien_reessayer' => 'zkusit znovu',
	'lien_repondre_message' => 'Odpovědět na zprávu',
	'lien_supprimer' => 'odstranit',
	'lien_tout_afficher' => 'Zobrazit vše',
	'lien_visite_site' => 'navštívit tyto stránky',
	'lien_visites' => '@visites@ návštěv',
	'lien_voir_auteur' => 'Zobrazit autora',
	'login_acces_prive' => 'přístup do neveřejné oblasti',
	'login_autre_identifiant' => 'použít jiné ID',
	'login_cookie_accepte' => 'Nastavte prohlížeč tak, aby je přijímal (alespoň pro tento web).',
	'login_cookie_oblige' => 'Pro bezpečnou identifikaci musí být povoleny soubory cookies.',
	'login_deconnexion_ok' => 'Byli jste odhlášeni.',
	'login_erreur_pass' => 'Nesprávné heslo.',
	'login_espace_prive' => 'neveřejná oblast',
	'login_identifiant_inconnu' => 'Identifikace "@login@" je neznámá.',
	'login_login' => 'Přihlášení:',
	'login_login2' => 'Přihlašovací údaje (identifikace pro připojení k těmto stránkám):', # MODIF
	'login_login_pass_incorrect' => '(Nesprávné uživatelské jméno nebo heslo).',
	'login_motpasseoublie' => 'zapomněli jste heslo?',
	'login_non_securise' => 'POZOR! Tento formulář není zabezpečený.
   Pokud nechcete, aby vaše heslo mohl někdo
   během přenosu po síti zachytit, zapněte v prohlížeči
   Javascript a',
	'login_nouvelle_tentative' => 'Další pokus',
	'login_par_ici' => 'Jste registrováni... takto...',
	'login_pass2' => 'Heslo:',
	'login_preferez_refuser' => '<b>Nechcete-li soubory cookies povolit</b>, existuje i jiný (méně bezpečný) způsob připojení:',
	'login_recharger' => 'znovu načíst tuto stránku',
	'login_rester_identifie' => 'Pamatovat moje ID několik dní',
	'login_retour_public' => 'Zpět na veřejné stránky',
	'login_retour_site' => 'Zpět na veřejné stránky',
	'login_retoursitepublic' => 'zpět na veřejné stránky',
	'login_sinscrire' => 'registrovat',
	'login_test_navigateur' => 'test prohlížeče/opakované připojení',
	'login_verifiez_navigateur' => '(Přesvědčte se však, zda si prohlížeč nezapamatoval vaše heslo...)',

	// M
	'masquer_trad' => 'skrýt překlady',
	'module_fichiers_langues' => 'Jazykové soubory',

	// N
	'navigateur_pas_redirige' => 'Nedojde-li k přesměrování prohlížeče, klepněte sem.',

	// O
	'onglet_affacer_base' => 'Odstranit databázi',
	'onglet_auteur' => 'Autor',
	'onglet_contenu_site' => 'Obsah webu',
	'onglet_evolution_visite_mod' => 'Úroveň návštěv',
	'onglet_fonctions_avances' => 'Rozšířené funkce',
	'onglet_informations_personnelles' => 'Osobní údaje',
	'onglet_interactivite' => 'Interaktivita',
	'onglet_messagerie' => 'Systém zpráv',
	'onglet_repartition_rubrique' => 'Rozdělení podle sekcí',
	'onglet_save_restaur_base' => 'Záloha/obnova databáze',
	'onglet_vider_cache' => 'Vymazat mezipamět (cache)',

	// P
	'pass_choix_pass' => 'Zadejte nové heslo:',
	'pass_erreur' => 'Chyba',
	'pass_erreur_acces_refuse' => '<b>Chyba:</b> K těmto stránkám již nemáte přístup.',
	'pass_erreur_code_inconnu' => '<b>Chyba:</b> Zadané kódy neodpovídají žádnému návštěvníkovi, který má k těmto stránkám přístup.',
	'pass_erreur_non_enregistre' => '<b>Chyba:</b> Adresa <tt>@email_oubli@</tt> není na těchto stránkách zaregistrována.',
	'pass_erreur_non_valide' => '<b>Chyba:</b> Neplatný e-mail <tt>@email_oubli@</tt>!',
	'pass_erreur_probleme_technique' => '<b>Chyba:</b> Z technických důvodů nebylo možné e-mail odeslat.',
	'pass_espace_prive_bla' => 'Neveřejná oblast stránek je návštěvníkům
přístupná po registraci. Jakmile se zaregistrujete,
budete moci korigovat rozpracované články,
předkládat články ke schválení a budete se moci účastnit diskusních skupin.',
	'pass_forum_bla' => 'Požádali jste o účast v diskusní skupině,
která je vyhrazena registrovaným uživatelům.',
	'pass_indiquez_cidessous' => 'Dále zadejte elektronickou adresu, pod kterou
jste již zaregistrováni. Obdržíte
e-mail, kde bude vysvětleno, jak
získáte přístup zpět.',
	'pass_mail_passcookie' => '(toto je automatická zpráva)
Přístup ke stránkám
@nom_site_spip@ (@adresse_site@)

získáte přechodem na adresu:

    @sendcookie@

Tam zadáte nové heslo
a znovu se ke stránkám připojíte.

',
	'pass_mot_oublie' => 'Zapomenuté heslo',
	'pass_nouveau_enregistre' => 'Nové heslo bylo zapsáno.',
	'pass_nouveau_pass' => 'Nové heslo',
	'pass_ok' => 'V pořádku',
	'pass_oubli_mot' => 'Zapomenuté heslo',
	'pass_quitter_fenetre' => 'Odejít z tohoto okna',
	'pass_rappel_login' => 'Připomenutí: Vaše uživatelské jméno (login) je "@login@".',
	'pass_recevoir_mail' => 'Obdržíte e-mail s vysvětlením, jak znovu získat přístup k těmto stránkám.',
	'pass_retour_public' => 'Zpět na veřejně přístupné stránky',
	'pass_rien_a_faire_ici' => 'Tady není co dělat :-).',
	'pass_vousinscrire' => 'Registrace přístupu na stránky',
	'precedent' => 'předchozí',
	'previsualisation' => 'Náhled',
	'previsualiser' => 'Náhled',

	// S
	'squelette' => 'šablona',
	'squelette_inclus_ligne' => 'vložená šablona, řádek',
	'squelette_ligne' => 'šablona, řádek',
	'stats_visites_et_popularite' => 'počet návštěv: @visites@; oblíbenost: @popularite@',
	'suivant' => 'další',

	// T
	'taille_ko' => '@taille@ kb',
	'taille_mo' => '@taille@ Mb',
	'taille_octets' => '@taille@ bytů',
	'texte_actualite_site_1' => 'Až se s rozhraním obeznámíte, klepněte na "',
	'texte_actualite_site_2' => 'úplné rozhraní',
	'texte_actualite_site_3' => '» ke zpřístupnění více funkcí.',
	'texte_creation_automatique_vignette' => 'Na těchto stránkách je zapnuta automatická tvorba náhledů a jejich předběžné zobrazení. Pokud pomocí tohoto formuláře nainstalujete obrázky ve formátu @gd_formats@, budou spojeny s náhledem, který má maximální velikost @taille_preview@ pixelů.',
	'texte_documents_associes' => 'S článkem jsou spojeny následující dokumenty,
    jež však do něj nejsou přímo
    vloženy. Podle veřejného vzhledu stránek
    se mohou zobrazit jako přiložené dokumenty.',
	'texte_erreur_mise_niveau_base' => 'Při aktualizaci databáze došlo k chybě.
      Obrázek <b>@fichier@</b> nebylo možné předat (článek @id_article@).<p>
      Pečlivě si poznamenejte toto číslo, zkuste aktualizaci
      a přesvědčte se, že obrázky jsou i nadále v článcích
      zobrazeny.', # MODIF
	'texte_inc_auth_1' => 'Přihlásili jsgte se jako
  <b>@auth_login@</b>, ale toto uživatelské jméno (již) v databázi neexistuje. 
  Zkuste', # MODIF
	'texte_inc_auth_2' => 'znovu připojit',
	'texte_inc_auth_3' => 'po opuštění
  restartujte v případě potřeby prohlížeč.',
	'texte_inc_config' => 'Níže uvedené úpravy významně ovlivňují
  fungování webu. Měnit tato nastavení by měli jenom uživatelé, kteří dobře vědí,
 jak systém SPIP funguje. <br /><br /><b>Obecně
 platí, že s těmito stránkami by měl pracovat pouze hlavní správce vašeho webu.</b>', # MODIF
	'texte_inc_meta_1' => 'Při pokusu o zápis do souboru  <code>@fichier@</code> došlo k systémové chybě. Jakožto správce webu',
	'texte_inc_meta_2' => 'zkontrolujte oprávnění k zápisu ',
	'texte_inc_meta_3' => 'do adresáře <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'rozpracované úpravy',
	'texte_statut_poubelle' => 'v koši',
	'texte_statut_propose_evaluation' => 'předloženo ke schválení',
	'texte_statut_publie' => 'zveřejněno online',
	'texte_statut_refuse' => 'odmítnuto',
	'titre_ajouter_mot_cle' => 'PŘIDAT KLÍČOVÉ SLOVO:',
	'titre_cadre_raccourcis' => 'KLÁVESOVÉ ZKRATKY:',
	'titre_changer_couleur_interface' => 'Změna barvy rozhraní',
	'titre_image_admin_article' => 'Máte možnost správy tohoto článku',
	'titre_image_administrateur' => 'Správce',
	'titre_image_aide' => 'Nápověda k položce',
	'titre_image_auteur_supprime' => 'Autor odstraněn',
	'titre_image_redacteur' => 'Redaktor bez přístupu',
	'titre_image_redacteur_02' => 'Redaktor',
	'titre_image_visiteur' => 'Návštěvník',
	'titre_joindre_document' => 'PŘIPOJIT DOKUMENT',
	'titre_mots_cles' => 'KLÍČOVÁ SLOVA',
	'titre_probleme_technique' => 'Varování: Z technických důvodů (server SQL) je tato část webu nepřístupná.<p>Děkujeme vám za pochopení.', # MODIF
	'titre_publier_document' => 'ZVEŘEJNIT DOKUMENT V TÉTO ČÁSTI',
	'titre_statistiques' => 'Statistiky stránek',
	'titre_titre_document' => 'Název dokumentu:',
	'trad_reference' => '(referenční článek)', # MODIF

	// Z
	'zbug_balise_b_aval' => ': tag B je příliš pozdě ve smyčce',
	'zbug_balise_inexistante' => 'error @from@: the #@balise@ tag does not exist', # MODIF
	'zbug_boucle' => 'smyčka',
	'zbug_boucle_recursive_undef' => 'nedefinovaná rekurzivní smyčka', # MODIF
	'zbug_champ_hors_boucle' => 'Pole @champ@ je mimo smyčku',
	'zbug_champ_hors_motif' => 'Pole @champ@ je mimo smyčku a má tag @motif@', # MODIF
	'zbug_code' => 'kód',
	'zbug_critere_inconnu' => 'neznámá podmínka @critere@', # MODIF
	'zbug_distant_interdit' => 'externí data jsou zakázána', # MODIF
	'zbug_doublon_table_sans_cle_primaire' => 'doublons used on a table which does not have a simple primary key', # MODIF
	'zbug_doublon_table_sans_index' => 'doubles in a table without an index', # MODIF
	'zbug_erreur_boucle_double' => 'SMYČKA@id@: dvojí definice', # MODIF
	'zbug_erreur_boucle_fermant' => 'SMYČKA@id@: chybí uzavírací tag', # MODIF
	'zbug_erreur_boucle_syntaxe' => 'Nesprávná syntax (BOUCLE)', # MODIF
	'zbug_erreur_execution_page' => 'chyba při výpočtu stránky', # MODIF
	'zbug_erreur_filtre' => 'Chyba - nedefinovaný filtr: <b>"@filtre@"</b>', # MODIF
	'zbug_erreur_meme_parent' => '{meme_parent} týká se jenom smyček (FORUMS) a (RUBRIQUES)', # MODIF
	'zbug_erreur_squelette' => 'Chyba či chyby v šabloně',
	'zbug_info_erreur_squelette' => 'Na webu došlo k chybě',
	'zbug_inversion_ordre_inexistant' => 'obrácené nebo neexistující pořadí', # MODIF
	'zbug_pagination_sans_critere' => '#PAGINATION tag without {pagination} criterion, or used in a recursive loop', # MODIF
	'zbug_parametres_inclus_incorrects' => 'Nesprávné parametry inkluze', # MODIF
	'zbug_resultat' => 'výsledky',
	'zbug_serveur_indefini' => 'Nedefinovaný server SQL', # MODIF
	'zbug_table_inconnue' => 'Neznámá tabulka SQL "@table@"'
);

?>
